@@ -13,12 +13,12 @@
 # limitations under the License.
 
 import json
-from typing import Optional
+from typing import Optional, List
 
-from cortex.client import Client
 from cortex.binary import run_cli
-from cortex.telemetry import sentry_wrapper
+from cortex.client import Client
 from cortex.exceptions import NotFound
+from cortex.telemetry import sentry_wrapper
 
 
 @sentry_wrapper
@@ -79,7 +79,7 @@ def new_client(
 
 
 @sentry_wrapper
-def env_list() -> list:
+def env_list() -> List:
     """
     List all environments configured on this machine.
     """
