@@ -12,30 +12,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import inspect
 import json
 import os
-import time
-import sys
-import subprocess
-import threading
-import yaml
-import uuid
-import dill
-import inspect
 import shutil
+import subprocess
+import sys
+import threading
+import time
+import uuid
 from pathlib import Path
+from typing import Optional, List, Dict, Any
 
-from typing import Optional
+import dill
+import yaml
 
-from cortex.binary import run_cli, get_cli_path
-from cortex.telemetry import sentry_wrapper
-from cortex.consts import EXPECTED_PYTHON_VERSION
 from cortex import util
+from cortex.binary import run_cli, get_cli_path
+from cortex.consts import EXPECTED_PYTHON_VERSION
+from cortex.telemetry import sentry_wrapper
+from cortex.exceptions import InvalidKindForMethod
 
 
 class Client:
     @sentry_wrapper
-    def __init__(self, env: dict):
+    def __init__(self, env: Dict):
         """
         A client to deploy and manage APIs in the specified environment.
 
@@ -47,23 +48,216 @@ class Client:
         self.env_name = env["name"]
 
     # CORTEX_VERSION_MINOR
-    @sentry_wrapper
-    def create_api(
+    def deploy(
         self,
-        api_spec: dict,
+        api_spec: Dict[str, Any],
+        project_dir: str,
+        force: bool = True,
+        wait: bool = False,
+    ):
+        """
+        Deploy API(s) from a project directory.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/ for schema.
+            project_dir: Path to a python project.
+            force: Override any in-progress api updates.
+            wait: Streams logs until the APIs are ready.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+        return self._create_api(
+            api_spec=api_spec,
+            project_dir=project_dir,
+            force=force,
+            wait=wait,
+        )
+
+    # CORTEX_VERSION_MINOR
+    def deploy_realtime_api(
+        self,
+        api_spec: Dict[str, Any],
+        handler,
+        requirements: Optional[List] = None,
+        conda_packages: Optional[List] = None,
+        force: bool = True,
+        wait: bool = False,
+    ) -> Dict:
+        """
+        Deploy a Realtime API.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/workloads/realtime-apis/configuration for schema.
+            handler: A Cortex Handler class implementation.
+            requirements: A list of PyPI dependencies that will be installed before the handler class implementation is invoked.
+            conda_packages: A list of Conda dependencies that will be installed before the handler class implementation is invoked.
+            force: Override any in-progress api updates.
+            wait: Streams logs until the APIs are ready.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+        kind = api_spec.get("kind")
+        if kind != "RealtimeAPI":
+            raise InvalidKindForMethod(
+                f"expected an api_spec with kind 'RealtimeAPI', got kind '{kind}' instead"
+            )
+
+        return self._create_api(
+            api_spec=api_spec,
+            handler=handler,
+            requirements=requirements,
+            conda_packages=conda_packages,
+            force=force,
+            wait=wait,
+        )
+
+    # CORTEX_VERSION_MINOR
+    def deploy_async_api(
+        self,
+        api_spec: Dict[str, Any],
+        handler,
+        requirements: Optional[List] = None,
+        conda_packages: Optional[List] = None,
+        force: bool = True,
+    ) -> Dict:
+        """
+        Deploy an Async API.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/workloads/async-apis/configuration for schema.
+            handler: A Cortex Handler class implementation.
+            requirements: A list of PyPI dependencies that will be installed before the handler class implementation is invoked.
+            conda_packages: A list of Conda dependencies that will be installed before the handler class implementation is invoked.
+            force: Override any in-progress api updates.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+        kind = api_spec.get("kind")
+        if kind != "AsyncAPI":
+            raise InvalidKindForMethod(
+                f"expected an api_spec with kind 'AsyncAPI', got kind '{kind}' instead"
+            )
+
+        return self._create_api(
+            api_spec=api_spec,
+            handler=handler,
+            requirements=requirements,
+            conda_packages=conda_packages,
+            force=force,
+        )
+
+    # CORTEX_VERSION_MINOR
+    def deploy_batch_api(
+        self,
+        api_spec: Dict[str, Any],
+        handler,
+        requirements: Optional[List] = None,
+        conda_packages: Optional[List] = None,
+    ) -> Dict:
+        """
+        Deploy a Batch API.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/workloads/batch-apis/configuration for schema.
+            handler: A Cortex Handler class implementation.
+            requirements: A list of PyPI dependencies that will be installed before the handler class implementation is invoked.
+            conda_packages: A list of Conda dependencies that will be installed before the handler class implementation is invoked.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+
+        kind = api_spec.get("kind")
+        if kind != "BatchAPI":
+            raise InvalidKindForMethod(
+                f"expected an api_spec with kind 'BatchAPI', got kind '{kind}' instead"
+            )
+
+        return self._create_api(
+            api_spec=api_spec,
+            handler=handler,
+            requirements=requirements,
+            conda_packages=conda_packages,
+        )
+
+    # CORTEX_VERSION_MINOR
+    def deploy_task_api(
+        self,
+        api_spec: Dict[str, Any],
+        task,
+        requirements: Optional[List] = None,
+        conda_packages: Optional[List] = None,
+    ) -> Dict:
+        """
+        Deploy a Task API.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/workloads/task-apis/configuration for schema.
+            task: A callable class implementation.
+            requirements: A list of PyPI dependencies that will be installed before the handler class implementation is invoked.
+            conda_packages: A list of Conda dependencies that will be installed before the handler class implementation is invoked.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+        kind = api_spec.get("kind")
+        if kind != "TaskAPI":
+            raise InvalidKindForMethod(
+                f"expected an api_spec with kind 'TaskAPI', got kind '{kind}' instead"
+            )
+
+        return self._create_api(
+            api_spec=api_spec,
+            task=task,
+            requirements=requirements,
+            conda_packages=conda_packages,
+        )
+
+    # CORTEX_VERSION_MINOR
+    def deploy_traffic_splitter(
+        self,
+        api_spec: Dict[str, Any],
+    ) -> Dict:
+        """
+        Deploy a Task API.
+
+        Args:
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/workloads/realtime-apis/traffic-splitter/configuration for schema.
+
+        Returns:
+            Deployment status, API specification, and endpoint for each API.
+        """
+        kind = api_spec.get("kind")
+        if kind != "TrafficSplitter":
+            raise InvalidKindForMethod(
+                f"expected an api_spec with kind 'TrafficSplitter', got kind '{kind}' instead"
+            )
+
+        return self._create_api(
+            api_spec=api_spec,
+        )
+
+    # CORTEX_VERSION_MINOR
+    @sentry_wrapper
+    def _create_api(
+        self,
+        api_spec: Dict,
         handler=None,
         task=None,
-        requirements=[],
-        conda_packages=[],
+        requirements: Optional[List] = None,
+        conda_packages: Optional[List] = None,
         project_dir: Optional[str] = None,
         force: bool = True,
         wait: bool = False,
-    ) -> list:
+    ) -> Dict:
         """
         Deploy an API.
 
         Args:
-            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.34/ for schema.
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.35/ for schema.
             handler: A Cortex Handler class implementation. Not required for TaskAPI/TrafficSplitter kinds.
             task: A callable class/function implementation. Not required for RealtimeAPI/BatchAPI/TrafficSplitter kinds.
             requirements: A list of PyPI dependencies that will be installed before the handler class implementation is invoked.
@@ -76,6 +270,9 @@ class Client:
             Deployment status, API specification, and endpoint for each API.
         """
 
+        requirements = requirements if requirements is not None else []
+        conda_packages = conda_packages if conda_packages is not None else []
+
         if project_dir is not None:
             if handler is not None:
                 raise ValueError(
@@ -111,7 +308,8 @@ class Client:
                 raise ValueError(f"`task` parameter cannot be specified for {api_kind}")
         else:
             raise ValueError(
-                f"invalid {api_kind} kind, `api_spec` must have the `kind` field set to one of the following kinds: {['TrafficSplitter', 'TaskAPI', 'BatchAPI', 'RealtimeAPI']}"
+                f"invalid {api_kind} kind, `api_spec` must have the `kind` field set to one of the following kinds: "
+                f"{['TrafficSplitter', 'TaskAPI', 'BatchAPI', 'RealtimeAPI']}"
             )
 
         if api_spec.get("name") is None:
@@ -157,9 +355,6 @@ class Client:
             if not inspect.isclass(handler):
                 raise ValueError("`handler` parameter must be a class definition")
 
-            impl_rel_path = self._save_impl(handler, project_dir, "handler")
-            api_spec["handler"]["path"] = impl_rel_path
-
             if api_spec.get("handler") is None:
                 raise ValueError("`api_spec` must have the `handler` section defined")
 
@@ -168,10 +363,14 @@ class Client:
                     "the `type` field in the `handler` section of the `api_spec` must be set (tensorflow or python)"
                 )
 
+            impl_rel_path = self._save_impl(handler, project_dir, "handler")
+            api_spec["handler"]["path"] = impl_rel_path
+
         if api_kind == "TaskAPI":
             if not callable(task):
                 raise ValueError(
-                    "`task` parameter must be a callable (e.g. a function definition or a class definition called `Task` with a `__call__` method implemented"
+                    "`task` parameter must be a callable (e.g. a function definition or a class definition called "
+                    "`Task` with a `__call__` method implemented "
                 )
 
             impl_rel_path = self._save_impl(task, project_dir, "task")
@@ -205,7 +404,7 @@ class Client:
         config_file: str,
         force: bool = False,
         wait: bool = False,
-    ) -> list:
+    ) -> Dict:
         """
         Deploy or update APIs specified in the config_file.
 
@@ -279,7 +478,7 @@ class Client:
         return api
 
     @sentry_wrapper
-    def get_api(self, api_name: str) -> dict:
+    def get_api(self, api_name: str) -> Dict:
         """
         Get information about an API.
 
@@ -295,7 +494,7 @@ class Client:
         return apis[0]
 
     @sentry_wrapper
-    def list_apis(self) -> list:
+    def list_apis(self) -> List:
         """
         List all APIs in the environment.
 
@@ -309,7 +508,7 @@ class Client:
         return json.loads(output.strip())
 
     @sentry_wrapper
-    def get_job(self, api_name: str, job_id: str) -> dict:
+    def get_job(self, api_name: str, job_id: str) -> Dict:
         """
         Get information about a submitted job.
 
@@ -343,7 +542,7 @@ class Client:
         run_cli(args, hide_output=True)
 
     @sentry_wrapper
-    def patch(self, api_spec: dict, force: bool = False) -> dict:
+    def patch(self, api_spec: Dict, force: bool = False) -> Dict:
         """
         Update the api specification for an API that has already been deployed.
 
@@ -366,7 +565,7 @@ class Client:
             return json.loads(output.strip())
 
     @sentry_wrapper
-    def delete_api(self, api_name: str, keep_cache: bool = False):
+    def delete(self, api_name: str, keep_cache: bool = False):
         """
         Delete an API.
 
